@@ -1,8 +1,8 @@
 from . import _base_imports
 
-from .api import Preql
+from .api import Preql, T
 from .exceptions import Signal
 
 # import importlib.metadata as importlib_metadata
 # __version__ = importlib_metadata.version("prql")
-__version__ = "0.1.18"
+__version__ = "0.1.19"
