@@ -544,7 +544,7 @@ def _compile_arith(state, arith, a: T.string, b: T.int):
 
 @dp_inst
 def _compile_arith(state, arith, a: T.number, b: T.number):
-    if arith.op == '/' or a.type <= T.float or b.type <= T.float:
+    if arith.op in ('/', '**') or a.type <= T.float or b.type <= T.float:
         res_type = T.float
     else:
         res_type = T.int
@@ -557,6 +557,7 @@ def _compile_arith(state, arith, a: T.number, b: T.number):
             '/': operator.truediv,
             '/~': operator.floordiv,
             '%': operator.mod,
+            '**': operator.pow,
         }[arith.op]
     except KeyError:
         raise Signal.make(T.TypeError, state, arith, f"Operator {arith.op} not supported between types '{a.type}' and '{b.type}'")
@@ -569,6 +570,8 @@ def _compile_arith(state, arith, a: T.number, b: T.number):
             value = f(a.local_value, b.local_value)
         except ZeroDivisionError as e:
             raise Signal.make(T.ValueError, state, arith.args[-1], str(e))
+        if arith.op == '**':
+            value = float(value)
         return new_value_instance(value, res_type)
 
     code = sql.arith(state.db.target, res_type, arith.op, [a.code, b.code])
@@ -617,8 +620,8 @@ def compile_to_inst(state: State, lst: objects.PythonList):
     t = lst.type.elem
     x = [sql.Primitive(t, sql._repr(t,i)) for i in (lst.items)]
     name = state.unique_name("list_")
-    table_code, subq = sql.create_list(lst.type, name, x)
-    inst = objects.ListInstance.make(table_code, lst.type, [])
+    table_code, subq, list_type = sql.create_list(name, x)
+    inst = objects.ListInstance.make(table_code, list_type, [])
     inst.subqueries[name] = subq
     return inst
 
@@ -631,16 +634,20 @@ def compile_to_inst(state: State, lst: ast.List_):
 
     elems = evaluate(state, lst.elems)
 
-    elem_type = union_types(e.type for e in elems)
+    types = {e.type for e in elems}
+
+    if len(types) > 1:
+        raise Signal.make(T.TypeError, state, lst, f"List members must be of the same type. Got {types}")
+
+    elem_type ,= types
 
     if not (elem_type <= T.union[T.primitive, T.nulltype]):
         raise Signal.make(T.TypeError, state, lst, "Cannot create lists of type %s" % elem_type)
 
-    assert elem_type <= lst.type.elems[ITEM_NAME]
+    assert elem_type <= lst.type.elems[ITEM_NAME], (elem_type, lst.type)
 
-    list_type = T.list[elem_type]
     name = state.unique_name("list_")
-    table_code, subq = sql.create_list(list_type, name, [e.code for e in elems])
+    table_code, subq, list_type = sql.create_list(name, [e.code for e in elems])
 
     inst = objects.ListInstance.make(table_code, list_type, elems)
     inst.subqueries[name] = subq
