@@ -888,8 +888,9 @@ def localize(state, inst: objects.Instance):
     # Cancel unoptimized mode? Or leave this unprotected?
     # state.require_access(state.AccessLevels.WRITE_DB)
 
-    if inst.type <= T.nulltype:
+    if inst.code is sql.null:
         return None
+
     return db_query(state, inst.code, inst.subqueries)
 
 @dy
@@ -917,7 +918,7 @@ def function_help_str(self, state):
         if p.type:
             s += f": {p.type}"
         if p.default:
-            s += f"={cast_to_python(state, p.default)}"
+            s += f"={p.default.repr(state)}"
         params.append(s)
 
     if self.param_collector is not None:
